# pyLFI

[![Project Status: WIP – Initial development is in progress, but there has not yet been a stable, usable release suitable for the public.](https://www.repostatus.org/badges/latest/wip.svg)](https://www.repostatus.org/#wip)
[![Documentation Status](https://readthedocs.org/projects/pylfi/badge/?version=latest)](https://pylfi.readthedocs.io/en/latest/?badge=latest)

pyLFI is a Python toolbox for likelihood-free inference (LFI) for estimating the posterior distributions of model parameters.

This repository provides a Python library for kernel density estimation. In comparison to other Python implementations of kernel density estimation, key features of this library include:

1. Support for weighted samples
2. A variety of kernels, including a smooth, compact kernel.

**Initial development is in progress, and there has not yet been a stable, usable release suitable for the public.**
